@@ -1,22 +1,20 @@
 #!/usr/bin/env python
-
-"""
-    A library that provides a Python interface to the Telegram Bot API
-    Copyright (C) 2015 Leandro Toledo de Souza <leandrotoeldodesouza@gmail.com>
-
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU Lesser Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU Lesser Public License for more details.
-
-    You should have received a copy of the GNU Lesser Public License
-    along with this program.  If not, see [http://www.gnu.org/licenses/].
-"""
+#
+# A library that provides a Python interface to the Telegram Bot API
+# Copyright (C) 2015 Leandro Toledo de Souza <leandrotoeldodesouza@gmail.com>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser Public License for more details.
+#
+# You should have received a copy of the GNU Lesser Public License
+# along with this program.  If not, see [http://www.gnu.org/licenses/].
 
 
 import json
@@ -304,7 +302,7 @@ class Bot(TelegramObject):
                      document,
                      reply_to_message_id=None,
                      reply_markup=None):
-        """Use this method to send Lesser files.
+        """Use this method to send general files.
 
         Args:
           chat_id:
@@ -372,6 +370,8 @@ class Bot(TelegramObject):
     def sendVideo(self,
                   chat_id,
                   video,
+                  duration=None,
+                  caption=None,
                   reply_to_message_id=None,
                   reply_markup=None):
         """Use this method to send video files, Telegram clients support mp4
@@ -384,6 +384,11 @@ class Bot(TelegramObject):
             Video to send. You can either pass a file_id as String to resend a
             video that is already on the Telegram servers, or upload a new
             video file using multipart/form-data.
+          duration:
+            Duration of sent video in seconds. [Optional]
+          caption:
+            Video caption (may also be used when resending videos by file_id).
+            [Optional]
           reply_to_message_id:
             If the message is a reply, ID of the original message. [Optional]
           reply_markup:
@@ -400,6 +405,11 @@ class Bot(TelegramObject):
         data = {'chat_id': chat_id,
                 'video': video}
 
+        if duration:
+            data['duration'] = duration
+        if caption:
+            data['caption'] = caption
+
         return url, data
 
     @log
@@ -460,7 +470,7 @@ class Bot(TelegramObject):
             - ChatAction.UPLOAD_PHOTO for photos,
             - ChatAction.UPLOAD_VIDEO or upload_video for videos,
             - ChatAction.UPLOAD_AUDIO or upload_audio for audio files,
-            - ChatAction.UPLOAD_DOCUMENT for Lesser files,
+            - ChatAction.UPLOAD_DOCUMENT for general files,
             - ChatAction.FIND_LOCATION for location data.
         """
 
@@ -663,3 +673,6 @@ class Bot(TelegramObject):
         if self.last_name:
             data['last_name'] = self.last_name
         return data
+
+    def __reduce__(self):
+        return (self.__class__, (self.token, self.base_url))
