@@ -1,22 +1,20 @@
 #!/usr/bin/env python
-
-"""
-    A library that provides a Python interface to the Telegram Bot API
-    Copyright (C) 2015 Leandro Toledo de Souza <leandrotoeldodesouza@gmail.com>
-
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU Lesser Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU Lesser Public License for more details.
-
-    You should have received a copy of the GNU Lesser Public License
-    along with this program.  If not, see [http://www.gnu.org/licenses/].
-"""
+#
+# A library that provides a Python interface to the Telegram Bot API
+# Copyright (C) 2015 Leandro Toledo de Souza <leandrotoeldodesouza@gmail.com>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser Public License for more details.
+#
+# You should have received a copy of the GNU Lesser Public License
+# along with this program.  If not, see [http://www.gnu.org/licenses/].
 
 
 from telegram import TelegramObject
@@ -37,6 +35,7 @@ class Message(TelegramObject):
                  photo=None,
                  sticker=None,
                  video=None,
+                 caption=None,
                  contact=None,
                  location=None,
                  new_chat_participant=None,
@@ -58,6 +57,7 @@ class Message(TelegramObject):
         self.photo = photo
         self.sticker = sticker
         self.video = video
+        self.caption = caption
         self.contact = contact
         self.location = location
         self.new_chat_participant = new_chat_participant
@@ -100,11 +100,6 @@ class Message(TelegramObject):
         else:
             reply_to_message = None
 
-        if 'text' in data:
-            text = data['text']
-        else:
-            text = None
-
         if 'audio' in data:
             from telegram import Audio
             audio = Audio.de_json(data['audio'])
@@ -166,12 +161,13 @@ class Message(TelegramObject):
                        forward_from=forward_from,
                        forward_date=data.get('forward_date', None),
                        reply_to_message=reply_to_message,
-                       text=text,
+                       text=data.get('text', ''),
                        audio=audio,
                        document=document,
                        photo=photo,
                        sticker=sticker,
                        video=video,
+                       caption=data.get('caption', ''),
                        contact=contact,
                        location=location,
                        new_chat_participant=new_chat_participant,
@@ -204,6 +200,8 @@ class Message(TelegramObject):
             data['sticker'] = self.sticker.to_dict()
         if self.video:
             data['video'] = self.video.to_dict()
+        if self.caption:
+            data['caption'] = self.caption
         if self.contact:
             data['contact'] = self.contact.to_dict()
         if self.location:
